@@ -805,7 +805,7 @@ def cloudScattering(q, cloud, relError=50, formfactoramp=None, V=None, rms=0, ff
         beta = (res[2] * res[2].conj()) / res[1]
         res[1] = res[1] / sumblength ** 2  # normalisation
         res[2] = res[2] / sumblength       # normalisation
-        result = dA(np.c_[res[0], res[1], beta, res[2]].T, dtype=np.float)
+        result = dA(np.c_[res[0], res[1], beta, res[2]].T, dtype=float)
         result.columnname = 'q; Pq; beta; fa'
 
     result.sumblength = sumblength
