@@ -54,8 +54,6 @@ In this case the multiprocessing is not used and the debugger finds the error co
 See example in doForList.
 
 """
-from __future__ import print_function
-from __future__ import division
 
 import scipy.constants as constants
 import multiprocessing as mp
@@ -496,20 +494,21 @@ def psphereAverage(funktion, relError=300, *args, **kwargs):
 # noinspection PyIncorrectDocstring
 def doForList(funktion, looplist, *args, **kwargs):
     """
-    Calculates function for values in looplist in a pool of workers in parallel using multiprocessing.
+    Apply function with values in looplist in a pool of workers in parallel using multiprocessing.
     
     Like multiprocessing map_async but distributes automatically all given arguments.
     
     Parameters
     ----------
     funktion : function
-        Function to process with arguments (looplist[i],args,kwargs)
+        Function to process with arguments (args, loopover[i]=looplist[j,i], kwargs)
         Return value of function should contain parameters or at least the loopover value to allow a check, if desired.
-    looplist : list
+    loopover : list of string, default= None
+        Names of arguments to use for (sync) looping over with values in looplist.
+        - If not given the first funktion argument is used.
+        - If loopover is single argument this gets looplist[i,:] .
+    looplist : list or array N x len(loopover)
         List of values to loop over.
-    loopover : string, int,default= Not given
-        Name of argument to use for looping over with values in looplist.
-        If not given the first argument is used, which should be not included as argument.
     ncpu : int, optional
         Number of cpus in the pool.
          - not given or 0   -> all cpus are used
@@ -518,7 +517,9 @@ def doForList(funktion, looplist, *args, **kwargs):
     cb : None, function
         Callback after each calculation.
     debug : int
-        debug > 0 allows serial output for testing
+        debug > 0 allows serial output for testing.
+    output : bool
+        If False no output is shown.
 
     Returns
     -------
@@ -531,20 +532,36 @@ def doForList(funktion, looplist, *args, **kwargs):
     E.g.::
 
      def f(x,a,b,c,d):
-         return [x,x+a+b+c+d]
+     result = x+a+b+c+d
+         return [x, result]
 
     Examples
     --------
     ::
 
+     import jscatter as js
+     import numpy as np
+
      def f(x,a,b,c,d):
         res=x+a+b+c+d
         return [x,res]
+
      # loop over first argument, here x
      res = js.parallel.doForList(f,looplist=np.arange(100),a=1,b=2,c=3,d=11)
      # loop over 'd' ignoring the given d=11 (which can be omitted here)
      res = js.parallel.doForList(f,looplist=np.arange(100),loopover='d',x=0,a=1,b=2,c=3,d=11)
 
+     # using a list of 2 values for x (is first argument)
+     def f(x,a,b,c,d):
+        res=x[0]+x[1]+a+b+c+d
+        return [x[0],res]
+     loop = np.arange(100).reshape(-1,2)  # has 2 values fin second dimension
+     res = js.parallel.doForList(f,looplist=loop,a=1,b=2,c=3,d=11)
+
+     # looping over several variables in sync
+     loop = np.arange(100).reshape(-1,2)
+     res = js.parallel.doForList(f,looplist=loop,loopover=['a','b'],x=[100,200],a=1,b=2,c=3,d=11)
+
     """
     output = kwargs.pop('output', True)
     ncpu = mp.cpu_count()
@@ -554,38 +571,53 @@ def doForList(funktion, looplist, *args, **kwargs):
         elif kwargs['ncpu'] > 0:
             ncpu = min(ncpu, kwargs['ncpu'])
         del kwargs['ncpu']
+
+    # check for callback
     cb = kwargs.pop('cb', None)
-    loopover = kwargs.pop('loopover', None)
+
+    # not given defaults to first varname in funktion
+    loopover = kwargs.pop('loopover', funktion.__code__.co_varnames[0])
+
     if ('debug' in kwargs and kwargs['debug'] > 0) or ncpu == 1:  # in sequence for testing purposes
-        if 'debug' in kwargs.keys():
-            del kwargs['debug']
+        _ = kwargs.pop('debug', None)
         res = []
-        if output: print('start NO pool; this is a test ')
+        if output:
+            print('start NO pool; this is a test ')
         if isinstance(loopover, str):
             for Q in looplist:
-                # noinspection PyCallingNonCallable
                 res.append(funktion(*args, **dict(kwargs, **{loopover: Q})))
-                if cb is not None:  cb(res[-1])
+                if cb is not None: cb(res[-1])
+        elif isinstance(loopover, (list, tuple)) and (len(loopover) == 1):
+            for Q in looplist:
+                res.append(funktion(*args, **dict(kwargs, **{loopover[0]: Q})))
+                if cb is not None: cb(res[-1])
         else:
             for Q in looplist:
-                # noinspection PyCallingNonCallable
-                res.append(funktion(*((Q,) + args), **kwargs))
-                if cb is not None:  cb(res[-1])
+                res.append(funktion(*args, **dict(kwargs, **dict(zip(loopover, Q)))))
+                if cb is not None: cb(res[-1])
+
     else:  # in parallel for production run
-        if 'debug' in kwargs: del kwargs['debug']
-        if output: print('start pool of ', ncpu)
+        _ = kwargs.pop('debug', None)
+        if output:
+            print('start pool of ', ncpu)
+
         pool = mp.Pool(ncpu)
         # we need to create a temporary dict that is given to a job and is not only a view to the updated kwargs
         # this is needed as the view changes to each new value in the loop even in the jobs
         if isinstance(loopover, str):
             jobs = [pool.apply_async(funktion, args, dict(kwargs, **{loopover: Q}), callback=cb) for Q in looplist]
+        elif isinstance(loopover, (list, tuple)) and (len(loopover) == 1):
+            jobs =[pool.apply_async(funktion, args, dict(kwargs, ** {loopover[0]: Q}), callback=cb) for Q in looplist]
         else:
-            jobs = [pool.apply_async(funktion, (Q,) + args, kwargs, callback=cb) for Q in looplist]
+            jobs = [pool.apply_async(funktion, args, dict(kwargs, **dict(zip(loopover, Q))), callback=cb)
+                    for Q in looplist]
         res = [job.get() for job in jobs]
+
         # clean up
         pool.close()
         pool.join()
-        if output: print('closed pool again')
+        if output:
+            print('closed pool again')
     return res
 
 
