@@ -33,6 +33,8 @@ provides the **sasImage** class to read and analyse 2D detector images from SAXS
 * 2D SAXS data can be read into **sasImage** to do typical tasks as transmission correction, masking,
   beamcenter location, 2D background subtraction, radial average (also for sectors).
 
+* Transmission correction and background correction are explained in :ref:`Analyse SAS data`
+
 * As **references** the waterXray scattering and a AgBe reference spectrum are available.
 
 * For form factors and structure factors see the respective modules. Conversion of sasImage to
@@ -1619,8 +1621,9 @@ def transmissionCorrection(data, dark, emptybeam=None, edge=0.03, exposure=None)
     Subtract dark current, find primary beam, get transmission count and normalize by transmission and exposure time.
     IN PLACE.
 
-    For measurements including the primary beam from a semitransparent beamstop as from SAXSpace.
+    Only for measurements including the primary beam from a semitransparent beamstop as from SAXSpace.
     The maximum of the primary beam peak after dark subtraction determines transmission counts.
+    For 2D images use sasImage.
 
 
     Parameters
